HRAP: Propulsion Analysis for Amateur Rocketry — hrap documentation

Skip to main content
`Ctrl`+`K`

# HRAP: Propulsion Analysis for Amateur Rocketry

Simple yet flexible

For basic usage, the API offers text-based configuration. Remaining flexible, advanced users can customize readily.

Performant

Thanks to JIT compilation, HRAP executes with performance comperable to similar C++ based software.

Monolithic

Through JAX, our Python code executes on both CPU (all major OS) and GPU (linux only).